@@ -198,7 +198,7 @@ test_that("Test discrete_coloring_categorical", {
   categories <- paste("Category", seq.int(5))
   col_palette <- viridis::magma(length(categories))
 
-  dc <- discrete_coloring_categorical(categories = categories, color_palette =  col_palette)
+  dc <- discrete_coloring_categorical(categories = categories, col_palette =  col_palette)
 
   expect_true(is(dc, "list"))
 
@@ -222,7 +222,7 @@ test_that("Test discrete_coloring_categorical", {
   categories <- as.factor(paste("Category", seq.int(5)))
   col_palette <- viridis::magma(length(categories))
 
-  dc <- discrete_coloring_categorical(categories = categories, color_palette =  col_palette)
+  dc <- discrete_coloring_categorical(categories = categories, col_palette =  col_palette)
   expect_true(is(dc, "list"))
 })
 
@@ -234,7 +234,7 @@ test_that("Test discrete_coloring_categorical with custom color ranges", {
   categories <- paste("Category", seq.int(5))
   col_palette <- viridis::magma(length(categories) * 2)
 
-  dc <- discrete_coloring_categorical(categories = categories, color_palette =  col_palette, range_max = max(stats::na.omit(df$occupancy)), range_min = min(stats::na.omit(df$occupancy)))
+  dc <- discrete_coloring_categorical(categories = categories, col_palette =  col_palette, range_max = max(stats::na.omit(df$occupancy)), range_min = min(stats::na.omit(df$occupancy)))
 
   expect_true(is(dc, "list"))
 
@@ -266,7 +266,7 @@ test_that("Test discrete_coloring_categorical input error handling", {
   expect_error(
     discrete_coloring_categorical(
       categories = as.list(categories),
-      color_palette =  col_palette,
+      col_palette =  col_palette,
       range_max = max(stats::na.omit(df$Besetzung)),
       range_min = min(stats::na.omit(df$Besetzung))
     )
@@ -274,7 +274,7 @@ test_that("Test discrete_coloring_categorical input error handling", {
   expect_error(
     discrete_coloring_categorical(
       categories = categories,
-      color_palette =  as.list(col_palette),
+      col_palette =  as.list(col_palette),
       range_max = max(stats::na.omit(df$Besetzung)),
       range_min = min(stats::na.omit(df$Besetzung))
     )
